` 
` Mark Claypool, Phong Le, Makoto Waseda and David Brown
` Worcester Polytechnic Institute, Worcester, MA
` Copyright 2000
`
`

Attribute VB_Name = "BasicModule"
Attribute VB_Ext_KEY = "RVB_UniqueId" ,"38F10ECD021C"

Option Explicit

'HWND_TOPMOST Places the window above all non-topmost windows. The window maintains
'its topmost position even when it is deactivated.
Public Const HWND_TOPMOST = -1


'The tagPOINT structure defines the x- and y- coordinates of a point
'Members : x (Specifies the x-coordinate of the point)
'          y (Specifies the y-coordinate of the point)
Public Type tagPOINT
    x As Long
    y As Long
End Type


'The RECT structure defines the coordinates of the upper-left and lower-right corners
'of a rectangle.
'Members : Left (Specifies the x-coordinate of the upper-left corner of the rectangle)
'          Top (Specifies the y-coordinate of the upper-left corner of the rectangle)
'          Right (Specifies the x-coordinate of the lower-right corner of the rectangle)
'          Bottom (Specifies the y-coordinate of the lower-right corner of the rectangle)
Public Type RECT
    Left As Long
    Top As Long
    Right As Long
    Bottom As Long
End Type


'The GetCursorPos function retrieves the cursor's position, in screen coordinates
'Parameters: lpPoint (Pointer to aPOINT structure that receives the screen coordinates
'                     of the cursor)
'Return Values: If the function succeeds, the return value is nonzero.
'               If the function fails, the return value is zero. To get extended error
'               information, callGetLastError.
Declare Function GetCursorPos Lib "user32" (lpPoint As tagPOINT) As Long


'The GetWindowRect function retrieves the dimensions of the bounding rectangle of
'the specified window. The dimensions are given in screen coordinates that are
'relative to the upper-left corner of the screen
'Parameters: hwnd (Handle to the window)
'            lpRect (Pointer to aRECT structure that receives the screen coordinates
'                    of the upper-left and lower-right corners of the window)
Declare Function GetWindowRect Lib "user32" (ByVal hwnd As Long, lpRect As RECT) As Long


'The GetCapture function retrieves the handle of the window (if any) that has captured
'the mouse. Only one window at a time can capture the mouse; this window receives mouse
'input whether or not the cursor is within its borders.
'Parameters: This function has no parameters
'Return Values: The return value is the handle of the capture window associated with
'               the current thread. If no window in the thread has captured the mouse,
'               the return value is NULL
Declare Function GetCapture Lib "user32" () As Long


'The GetTickCount function retrieves the number of milliseconds that have elapsed
'since the system was started. It is limited to the resolution of the system timer.
'If you need a higher resolution timer, use a multimedia timer or a high-resolution timer.
'Parameters: This function has no parameters
'Return Values: The return value is the number of milliseconds that have elapsed
'               since the system was started
Declare Function GetTickCount Lib "kernel32" () As Long


'The IsIconic function determines whether the specified window is minimized (iconic)
'Parameters: hwnd (Handle to the window to test)
'Return Values: If the window is iconic, the return value is nonzero
'               If the window is not iconic, the return value is zero
Declare Function IsIconic Lib "user32" (ByVal hwnd As Long) As Long


'The GetActiveWindow function retrieves the window handle to the active window
'associated with the calling thread's message queue
'Parameters: This function has no parameters
'Return Values: The return value is the handle to the active window associated with
'the calling thread's message queue. Otherwise, the return value is NULL
Declare Function GetActiveWindow Lib "user32" () As Long


'The SetWindowPos function changes the size, position, and Z order of a child, pop-up,
'or top-level window. Child, pop-up, and top-level windows are ordered according to
'their appearance on the screen. The topmost window receives the highest rank and
'is the first window in the Z order
'Parameters: hwnd (Handle to the window)
'            hWndInsertAfter (Handle to the window to precede the positioned window
'                             in the Z order. This parameter must be a window handle
'                             or one of the following values: Value Meaning)
'                             HWND_BOTTOM Places the window at the bottom of the Z order.
'                                         If the hWnd parameter identifies a topmost window,
'                                         the window loses its topmost status and is placed
'                                         at the bottom of all other windows.
'                             HWND_NOTOPMOST Places the window above all non-topmost windows
'                                            (that is, behind all topmost windows).
'                                            This flag has no effect if the window is
'                                            already a non-topmost window.
'                             HWND_TOP Places the window at the top of the Z order.
'                             HWND_TOPMOST Places the window above all non-topmost windows.
'                                          The window maintains its topmost position
'                                          even when it is deactivated.
'           x (Specifies the new position of the left side of the window,
'              in client coordinates.)
'           y (Specifies the new position of the top of the window,
'              in client coordinates.)
'           cx (Specifies the new width of the window, in pixels.)
'           cy (Specifies the new height of the window, in pixels.)
'           wFlags (Specifies the window sizing and positioning flags.
'                   This parameter can be a combination of the following values:
'                   Value Meaning)
'                   SWP_ASYNCWINDOWPOS If the calling thread does not own the window,
'                                      the system posts the request to the thread that
'                                      owns the window. This prevents the calling thread
'                                      from blocking its execution while other threads
'                                      process the request.
'                   SWP_DEFERERASE Prevents generation of the WM_SYNCPAINT message.
'                   SWP_DRAWFRAME Draws a frame (defined in the window's class description)
'                                 around the window.
'                   SWP_FRAMECHANGED Sends a WM_NCCALCSIZE message to the window,
'                                    even if the window's size is not being changed.
'                                    If this flag is not specified, WM_NCCALCSIZE is
'                                    sent only when the window's size is being changed.
'                   SWP_HIDEWINDOW Hides the window.
'                   SWP_NOACTIVATE Does not activate the window. If this flag is not set,
'                                  the window is activated and moved to the top of either
'                                  the topmost or non-topmost group (depending on
'                                   the setting of the hWndInsertAfter parameter).
'                   SWP_NOCOPYBITS Discards the entire contents of the client area.
'                                  If this flag is not specified, the valid contents of
'                                  the client area are saved and copied back into the client area
'                                  after the window is sized or repositioned.
'                   SWP_NOMOVE Retains the current position (ignores the X and Y parameters).
'                   SWP_NOOWNERZORDER Does not change the owner window's position
'                                     in the Z order.
'                   SWP_NOREDRAW Does not redraw changes. If this flag is set,
'                                no repainting of any kind occurs. This applies to
'                                the client area, the nonclient area (including
'                                the title bar and scroll bars), and any part of
'                                the parent window uncovered as a result of the window
'                                being moved. When this flag is set, the application
'                                must explicitly invalidate or redraw any parts of the
'                                window and parent window that need redrawing.
'                   SWP_NOREPOSITION Same as the SWP_NOOWNERZORDER flag.
'                   SWP_NOSENDCHANGING Prevents the window from receiving
'                                      the WM_WINDOWPOSCHANGING message.
'                   SWP_NOSIZE Retains the current size (ignores the cx and cy parameters).
'                   SWP_NOZORDER Retains the current Z order
'                                (ignores the hWndInsertAfter parameter).
'                   SWP_SHOWWINDOW Displays the window.
Declare Function SetWindowPos Lib "user32" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long) As Long
